==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/cs.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'cs', {
	acccessKey: 'Přístupový klíč',
	advanced: 'Rozšířené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulek',
	anchor: {
		toolbar: 'Záložka',
		menu: 'Vlastnosti záložky',
		title: 'Vlastnosti záložky',
		name: 'Název záložky',
		errorName: 'Zadejte prosím název záložky',
		remove: 'Odstranit záložku'
	},
	anchorId: 'Podle Id objektu',
	anchorName: 'Podle jména kotvy',
	charset: 'Přiřazená znaková sada',
	cssClasses: 'Třída stylu',
	emailAddress: 'E-mailová adresa',
	emailBody: 'Tělo zprávy',
	emailSubject: 'Předmět zprávy',
	id: 'Id',
	info: 'Informace o odkazu',
	langCode: 'Kód jazyka',
	langDir: 'Směr jazyka',
	langDirLTR: 'Zleva doprava (LTR)',
	langDirRTL: 'Zprava doleva (RTL)',
	menu: 'Změnit odkaz',
	name: 'Jméno',
	noAnchors: '(Ve stránce není definována žádná kotva!)',
	noEmail: 'Zadejte prosím e-mailovou adresu',
	noUrl: 'Zadejte prosím URL odkazu',
	other: '<jiný>',
	popupDependent: 'Závislost (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacího okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Levý okraj',
	popupLocationBar: 'Panel umístění',
	popupMenuBar: 'Panel nabídky',
	popupResizable: 'Umožňující měnit velikost',
	popupScrollBars: 'Posuvníky',
	popupStatusBar: 'Stavový řádek',
	popupToolbar: 'Panel nástrojů',
	popupTop: 'Horní okraj',
	rel: 'Vztah',
	selectAnchor: 'Vybrat kotvu',
	styles: 'Styl',
	tabIndex: 'Pořadí prvku',
	target: 'Cíl',
	targetFrame: '<rámec>',
	targetFrameName: 'Název cílového rámu',
	targetPopup: '<vyskakovací okno>',
	targetPopupName: 'Název vyskakovacího okna',
	title: 'Odkaz',
	toAnchor: 'Kotva v této stránce',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstranit odkaz',
	upload: 'Odeslat'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/cs.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'cs', {
	acccessKey: 'Přístupový klíč',
	advanced: 'Rozšířené',
	advisoryContentType: 'Pomocný typ obsahu',
	advisoryTitle: 'Pomocný titulek',
	anchor: {
		toolbar: 'Záložka',
		menu: 'Vlastnosti záložky',
		title: 'Vlastnosti záložky',
		name: 'Název záložky',
		errorName: 'Zadejte prosím název záložky',
		remove: 'Odstranit záložku'
	},
	anchorId: 'Podle Id objektu',
	anchorName: 'Podle jména kotvy',
	charset: 'Přiřazená znaková sada',
	cssClasses: 'Třída stylu',
	download: 'Force Download', // MISSING
	displayText: 'Zobrazit text',
	emailAddress: 'E-mailová adresa',
	emailBody: 'Tělo zprávy',
	emailSubject: 'Předmět zprávy',
	id: 'Id',
	info: 'Informace o odkazu',
	langCode: 'Kód jazyka',
	langDir: 'Směr jazyka',
	langDirLTR: 'Zleva doprava (LTR)',
	langDirRTL: 'Zprava doleva (RTL)',
	menu: 'Změnit odkaz',
	name: 'Jméno',
	noAnchors: '(Ve stránce není definována žádná kotva!)',
	noEmail: 'Zadejte prosím e-mailovou adresu',
	noUrl: 'Zadejte prosím URL odkazu',
	noTel: 'Please type the phone number', // MISSING
	other: '<jiný>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Závislost (Netscape)',
	popupFeatures: 'Vlastnosti vyskakovacího okna',
	popupFullScreen: 'Celá obrazovka (IE)',
	popupLeft: 'Levý okraj',
	popupLocationBar: 'Panel umístění',
	popupMenuBar: 'Panel nabídky',
	popupResizable: 'Umožňující měnit velikost',
	popupScrollBars: 'Posuvníky',
	popupStatusBar: 'Stavový řádek',
	popupToolbar: 'Panel nástrojů',
	popupTop: 'Horní okraj',
	rel: 'Vztah',
	selectAnchor: 'Vybrat kotvu',
	styles: 'Styl',
	tabIndex: 'Pořadí prvku',
	target: 'Cíl',
	targetFrame: '<rámec>',
	targetFrameName: 'Název cílového rámu',
	targetPopup: '<vyskakovací okno>',
	targetPopupName: 'Název vyskakovacího okna',
	title: 'Odkaz',
	toAnchor: 'Kotva v této stránce',
	toEmail: 'E-mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Odkaz',
	type: 'Typ odkazu',
	unlink: 'Odstranit odkaz',
	upload: 'Odeslat'
} );
